// $Id$
package org.jpl7;

class Version {
	public final int major = 7;
	public final int minor = 4; // jref as blob
	public final int patch = 0;
	public final String status = "alpha";
}
